@@ -28,7 +28,7 @@ def main():
 
 def parse_args(args):
     description = BOLD+'gapmm2: gapped alignment with minimap2.'+END_FORMATTING+\
-        ' Performs minimap2/mappy alignment with splice options and refines terminal alignments with edlib. Output is PAF format.'
+        ' Performs minimap2/mappy alignment with splice options and refines terminal alignments with edlib.'
     parser = MyParser(description=description, formatter_class=MyHelpFormatter, add_help=False)
     required_args = parser.add_argument_group('Positional arguments')
     required_args.add_argument('reference', help='reference genome (FASTA)')
@@ -36,6 +36,8 @@ def parse_args(args):
 
     optional_args = parser.add_argument_group('Optional arguments')
     optional_args.add_argument('-o', '--out', help='output in PAF format (default: stdout)', metavar='')
+    optional_args.add_argument('-f', '--out-format', dest='out_fmt', default='paf',
+                               choices=['paf', 'gff3'], help='output format [paf,gff3]', metavar='')
     optional_args.add_argument('-t', '--threads', type=int, default=3, help='number of threads to use with minimap2 (default: 3)', metavar='')
     optional_args.add_argument('-m', '--min-mapq', dest='min_mapq', default=1, help='minimum map quality value', metavar='')
     optional_args.add_argument('-i', '--max-intron', dest='max_intron', type=int, default=500, help='max intron length, controls terminal search space', metavar='')
@@ -44,7 +46,7 @@ def parse_args(args):
     help_args = parser.add_argument_group('Help')
     help_args.add_argument('-h', '--help', action='help', default=argparse.SUPPRESS,
                            help='Show this help message and exit')
-    help_args.add_argument('--version', action='version', version='GFFtk v' + __version__,
+    help_args.add_argument('--version', action='version', version='gapmm2 v' + __version__,
                            help="Show program's version number and exit")
 
     if len(args) == 0:
